.. _gwcs-schemas:
   
GWCS Schema Definitions
=======================

WCS object
----------

.. asdf-autoschemas::
	     
  wcs-1.0.0
  step-1.0.0


Coordinate Frames
-----------------

.. asdf-autoschemas::
	     
  celestial_frame-1.0.0
  frame-1.0.0
  spectral_frame-1.0.0
  frame2d-1.0.0
  temporal_frame-1.0.0
  composite_frame-1.0.0

Transforms
----------

.. asdf-autoschemas::
	     
  label_mapper-1.0.0
  regions_selector-1.0.0
